==> snapshot.2000-11-22_08-28.tar.gz: phpPgAdmin/func_create.php <==
<?php
/* $Id: func_create.php,v 1.1.1.1 2000/11/10 04:35:55 dwilson Exp $ */

include("header.inc.php");

if (!isset($submit)) {
	?>
	<form method=POST>
	<table border="<?php echo $cfgBorder; ?>">
	<tr>
		<th><?php echo $strFunc; ?></th>
		<th><?php echo $strArgs; ?></th>
		<th><?php echo $strRetType; ?></th>
		<th><?php echo $strLang; ?></th>
	</tr>
	<tr>
		<td><input type="text" name="function"></td>
		<td><input type="text" name="arglist"></td>
		<td>
			<select name="returns">
			<?php
			$sql_get_types = "
				(
				SELECT typname 
				FROM pg_type pt
				WHERE typname NOT LIKE '\\\_%' 
				)
				EXCEPT
				(
				SELECT relname
				FROM pg_class
				WHERE 
					relkind = 'S' OR relname LIKE 'pg%'
				)
				";
			$types = pg_exec($link, pre_query($sql_get_types)) or pg_die(pg_errormessage());
			for ($i_type = 0; $i_type < @pg_numrows($types); $i_type++) {
				$typename = pg_result($types, $i_type, "typname");
				echo "<option value=\"$typename\">$typename";
			}
			?>
			</select>
		</td>
		<td>
			<select name="language">
			<?php
			$sql_get_langs = "SELECT lanname FROM pg_language ORDER BY lanname";
			$langs = pg_exec($link, pre_query($sql_get_langs)) or pg_die(pg_errormessage(), $sql_get_langs);
			for ($i_lang = 0; $i_lang < @pg_numrows($langs); $i_lang++) {
				$langname = pg_result($langs, $i_lang, "lanname");
				echo "<option value=\"$langname\">$langname";
			}
			?>
			</select>
		</td>
	</tr>
	<tr><th colspan=4><?php echo $strSrc; ?></th></tr>
	<tr>
		<td colspan=4><textarea name=source wrap=virtual cols=80 rows=10></textarea></td>
	</tr>
	<tr>
		<td align=center colspan=4>
		<input type=submit name=submit value="create function">
		<input type=reset>
		</td>
	</tr>
	</table>
	</form>
	<?php
} else {
	// $source = stripslashes($source);
	$sql_query = "CREATE FUNCTION $cfgQuotes$function$cfgQuotes($arglist) RETURNS $returns AS '$source' LANGUAGE '$language'";
	echo $strDoYouReally . " " . $sql_query;
	?>
	<form method=POST action="sql.php">
	<input type=hidden name="db" value="<?php echo $db; ?>">
	<input type=hidden name="server" value="<?php echo $server; ?>">
	<input type=hidden name="sql_query" value="<?php echo urlencode($sql_query); ?>">
	<input type=hidden name="goto" value="db_details.php">
	<input type=hidden name="rel_type" value="function">
	<input type=submit name="btnDrop" value="<?php echo $strYes; ?>">
	<input type=submit name="btnDrop" value="<?php echo $strNo; ?>">
	</form>
	<?php
}

include("footer.inc.php");
?>

==> snapshot.2000-11-28_04-00.tar.gz: phpPgAdmin/func_create.php <==
<?php
/* $Id: func_create.php,v 1.2 2000/11/26 10:58:38 chriskl Exp $ */

include("header.inc.php");

if (!isset($submit)) {
	?>
	<form method=POST>
	<table border="<?php echo $cfgBorder; ?>">
	<tr>
		<th><?php echo $strFunc; ?></th>
		<th><?php echo $strArgs; ?></th>
		<th><?php echo $strRetType; ?></th>
		<th><?php echo $strLang; ?></th>
	</tr>
	<tr>
		<td><input type="text" name="function"></td>
		<td><input type="text" name="arglist"></td>
		<td>
			<select name="returns">
			<?php
			$sql_get_types = "
				(
				SELECT typname 
				FROM pg_type pt
				WHERE typname NOT LIKE '\\\_%' 
				)
				EXCEPT
				(
				SELECT relname
				FROM pg_class
				WHERE 
					relkind = 'S' OR relname LIKE 'pg%'
				)
				";
			$types = pg_exec($link, pre_query($sql_get_types)) or pg_die(pg_errormessage());
			for ($i_type = 0; $i_type < @pg_numrows($types); $i_type++) {
				$typename = pg_result($types, $i_type, "typname");
				echo "<option value=\"$typename\">$typename";
			}
			?>
			</select>
		</td>
		<td>
			<select name="language">
			<?php
			$sql_get_langs = "SELECT lanname FROM pg_language ORDER BY lanname";
			$langs = pg_exec($link, pre_query($sql_get_langs)) or pg_die(pg_errormessage(), $sql_get_langs);
			for ($i_lang = 0; $i_lang < @pg_numrows($langs); $i_lang++) {
				$langname = pg_result($langs, $i_lang, "lanname");
				echo "<option value=\"$langname\">$langname";
			}
			?>
			</select>
		</td>
	</tr>
	<tr><th colspan=4><?php echo $strSrc; ?></th></tr>
	<tr>
		<td colspan=4><textarea name=source wrap=virtual cols=80 rows=10></textarea></td>
	</tr>
	<tr>
		<td align=center colspan=4>
		<input type=submit name=submit value="<?php echo "$strCreate $strFunc"; ?>">
		<input type=reset>
		</td>
	</tr>
	</table>
	</form>
	<?php
} else {
	// $source = stripslashes($source);
	$sql_query = "CREATE FUNCTION $cfgQuotes$function$cfgQuotes($arglist) RETURNS $returns AS '$source' LANGUAGE '$language'";
	echo $strDoYouReally . " " . htmlspecialchars($sql_query);
	?>
	<form method=POST action="sql.php">
	<input type=hidden name="db" value="<?php echo $db; ?>">
	<input type=hidden name="server" value="<?php echo $server; ?>">
	<input type=hidden name="sql_query" value="<?php echo htmlspecialchars($sql_query); ?>">
	<input type=hidden name="goto" value="db_details.php">
	<input type=hidden name="rel_type" value="function">
	<input type=submit name="btnDrop" value="<?php echo $strYes; ?>">
	<input type=submit name="btnDrop" value="<?php echo $strNo; ?>">
	</form>
	<?php
}

include("footer.inc.php");
?>
